==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/usrstng_main.php <==
<?php
//==============================================================
// Program Name		: menu
// File Name		: usrstng_main.php
//--------------------------------------------------------------
// Date             : 2001/01/15
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");
require("common_login.php");	// 


define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");	// 򥤥᡼
define("TBL_NAME", "usrstng_pglist");					// ץꥹȥơ֥̾


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start(PG_NAME());

// HTMLإå
include("common_printheader.inc");

if (isset($mode)) {
	if (strtolower($mode) == "user" || empty($mode))
		$perm_flag = "U";
	else
		$perm_flag = "A";
} else {
	$perm_flag = "U";
}

print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"600\" bgcolor=\"white\">\n");
print("<tr align=\"center\">\n");
if ($perm_flag == "U") {
	print("<td class=\"color00\" width=\"50%\"><font color=\"white\"><b>桼˥塼</b></font></td>\n");
	printf("<td width=\"300\" bgcolor=\"#cccccc\"><a href=\"%s?mode=admin\">ѥ˥塼</a></td>\n", $PHP_SELF);
} else {
	printf("<td bgcolor=\"#cccccc\" width=\"50%%\"><a href=\"%s?mode=user\">桼˥塼</a></td>\n", $PHP_SELF);
	print("<td width=\"300\" class=\"color00\"><font color=\"white\"><b>ѥ˥塼</b></font></td>\n");
}
print("</tr>\n");
print("<tr>\n");
printf("<td colspan=\"2\" class=\"color00\"><img height=\"1\" width=\"1\" src=\"%s\"></td>\n", SPACE_GIF_FILE);
print("</tr>\n");
print("<tr><td colspan=\"2\">\n");
print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"2\" width=\"100%\">\n");
print("<tr class=\"color01\" align=\"center\">\n");
print("<td><b>ǽ</b></td>\n");
print("<td><b></b></td>\n");
print("</tr>\n");

$db = new DB_Test;
$query_str = sprintf("SELECT * FROM %s WHERE perm_flag='%s' order by menu_id", TBL_NAME, $perm_flag);
$db->query($query_str);

while ($db->next_record()) {
	$pgname = htmlspecialchars($db->f("filename"));
	$title = htmlspecialchars($db->f("pg_title"));
	$note = htmlspecialchars($db->f("biko"));
	print("<tr bgcolor=\"f7f2e8\">\n");
	if ($perm_flag == "A" && $JJ_PERMISSION != "admin")
		printf("<td>%s</td>\n", $title);
	else
		printf("<td><a href=\"%s\">%s</a></td>\n", $pgname, $title);
	printf("<td>%s</td>\n", $note);
	print("</tr>\n");
}
$db->close();

print("</table>\n");
print("</td></tr>\n");
print("</table>\n");

// HTMLեå
include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/usrstng_main.php <==
<?php
//==============================================================
// Program Name		: menu
// File Name		: usrstng_main.php
//--------------------------------------------------------------
// Date             : 2001/01/15
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("common_login.php");	// 


define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");	// 򥤥᡼
define("TBL_NAME", "usrstng_pglist");					// ץꥹȥơ֥̾


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start(PG_NAME());

// HTMLإå
include("common_printheader.inc");

if (isset($mode)) {
	if (strtolower($mode) == "user" || empty($mode))
		$perm_flag = "U";
	else
		$perm_flag = "A";
} else {
	$perm_flag = "U";
}

print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"600\" bgcolor=\"white\">\n");
print("<tr align=\"center\">\n");
if ($perm_flag == "U") {
	print("<td class=\"color00\" width=\"50%\"><font color=\"white\"><b>桼˥塼</b></font></td>\n");
	printf("<td width=\"300\" bgcolor=\"#cccccc\"><a href=\"%s?mode=admin\">ѥ˥塼</a></td>\n", $PHP_SELF);
} else {
	printf("<td bgcolor=\"#cccccc\" width=\"50%%\"><a href=\"%s?mode=user\">桼˥塼</a></td>\n", $PHP_SELF);
	print("<td width=\"300\" class=\"color00\"><font color=\"white\"><b>ѥ˥塼</b></font></td>\n");
}
print("</tr>\n");
print("<tr>\n");
printf("<td colspan=\"2\" class=\"color00\"><img height=\"1\" width=\"1\" src=\"%s\"></td>\n", SPACE_GIF_FILE);
print("</tr>\n");
print("<tr><td colspan=\"2\">\n");
print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"2\" width=\"100%\">\n");
print("<tr class=\"color01\" align=\"center\">\n");
print("<td><b>ǽ</b></td>\n");
print("<td><b></b></td>\n");
print("</tr>\n");

$db = new DB_Test;
$query_str = sprintf("SELECT * FROM %s WHERE perm_flag='%s' order by menu_id", TBL_NAME, $perm_flag);
$db->query($query_str);

while ($db->next_record()) {
	$pgname = htmlspecialchars($db->f("filename"));
	$title = htmlspecialchars($db->f("pg_title"));
	$note = htmlspecialchars($db->f("biko"));
	print("<tr bgcolor=\"f7f2e8\">\n");
	if ($perm_flag == "A" && $JJ_PERMISSION != "admin")
		printf("<td>%s</td>\n", $title);
	else
		printf("<td><a href=\"%s\">%s</a></td>\n", $pgname, $title);
	printf("<td>%s</td>\n", $note);
	print("</tr>\n");
}
$db->close();

print("</table>\n");
print("</td></tr>\n");
print("</table>\n");

// HTMLեå
include("common_printfooter.inc");

?>
